window.Gleam.initSearch([{"doc":"gleam_zlists","title":"gleam_zlists","content":"# gleam_zlists\n\nA library for working with **lazy lists** in **Gleam**.\n\nIt is a wrapper for [vjache/erlang-zlists](https://github.com/vjache/erlang-zlists), enriched with more functions.\n\nThe documentation is available on [HexDocs](https://hexdocs.pm/gleam_zlists/gleam_zlists.html).\n\n## Installation\n\nAdd `gleam_zlists` to your Gleam project.\n\n```\ngleam add gleam_zlists\n```\n\n## Examples\n\n```gleam\nimport gleam_zlists as zlist\n\n[2, 4, 6]\n|&gt; zlist.of_list\n|&gt; zlist.all(int.is_even)\n// True\n\n[1, 2, 3]\n|&gt; zlist.of_list\n|&gt; zlist.reverse\n|&gt; zlist.to_list\n// [3, 2, 1]\n\n[&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]\n|&gt; zlist.of_list\n|&gt; zlist.with_index\n|&gt; zlist.to_list\n// [#(&quot;a&quot;, 0), #(&quot;b&quot;, 1), #(&quot;c&quot;, 2)]\n```\n","url":"index.html"},{"doc":"gleam_zlists/interop","title":"ZList","content":"pub type ZList(a)\n\n\nSynonyms:\ngleam_zlists/interop.ZList\ngleam_zlists/interop ZList","url":"gleam_zlists/interop.html#ZList"},{"doc":"gleam_zlists/interop","title":"append","content":"pub fn append(x: ZList(ZList(a))) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.append\ngleam_zlists/interop append","url":"gleam_zlists/interop.html#append"},{"doc":"gleam_zlists/interop","title":"cartesian","content":"pub fn cartesian(x: ZList(a), y: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.cartesian\ngleam_zlists/interop cartesian","url":"gleam_zlists/interop.html#cartesian"},{"doc":"gleam_zlists/interop","title":"count","content":"pub fn count(x: ZList(a)) -&gt; Int\n\nSynonyms:\ngleam_zlists/interop.count\ngleam_zlists/interop count","url":"gleam_zlists/interop.html#count"},{"doc":"gleam_zlists/interop","title":"drop","content":"pub fn drop(x: Int, y: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.drop\ngleam_zlists/interop drop","url":"gleam_zlists/interop.html#drop"},{"doc":"gleam_zlists/interop","title":"dropwhile","content":"pub fn dropwhile(x: fn(a) -&gt; Bool, y: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.dropwhile\ngleam_zlists/interop dropwhile","url":"gleam_zlists/interop.html#dropwhile"},{"doc":"gleam_zlists/interop","title":"expand","content":"pub fn expand(x: ZList(a)) -&gt; List(a)\n\nSynonyms:\ngleam_zlists/interop.expand\ngleam_zlists/interop expand","url":"gleam_zlists/interop.html#expand"},{"doc":"gleam_zlists/interop","title":"filter","content":"pub fn filter(x: fn(a) -&gt; Bool, y: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.filter\ngleam_zlists/interop filter","url":"gleam_zlists/interop.html#filter"},{"doc":"gleam_zlists/interop","title":"foldl","content":"pub fn foldl(x: fn(a, b) -&gt; b, y: b, z: ZList(a)) -&gt; b\n\nSynonyms:\ngleam_zlists/interop.foldl\ngleam_zlists/interop foldl","url":"gleam_zlists/interop.html#foldl"},{"doc":"gleam_zlists/interop","title":"foreach","content":"pub fn foreach(x: fn(a) -&gt; b, y: ZList(a)) -&gt; Nil\n\nSynonyms:\ngleam_zlists/interop.foreach\ngleam_zlists/interop foreach","url":"gleam_zlists/interop.html#foreach"},{"doc":"gleam_zlists/interop","title":"generate","content":"pub fn generate(x: ZList(a), y: fn(a) -&gt; ZList(b)) -&gt; ZList(b)\n\nSynonyms:\ngleam_zlists/interop.generate\ngleam_zlists/interop generate","url":"gleam_zlists/interop.html#generate"},{"doc":"gleam_zlists/interop","title":"map","content":"pub fn map(x: fn(a) -&gt; b, y: ZList(a)) -&gt; ZList(b)\n\nSynonyms:\ngleam_zlists/interop.map\ngleam_zlists/interop map","url":"gleam_zlists/interop.html#map"},{"doc":"gleam_zlists/interop","title":"merge","content":"pub fn merge(x: ZList(a), y: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.merge\ngleam_zlists/interop merge","url":"gleam_zlists/interop.html#merge"},{"doc":"gleam_zlists/interop","title":"new_1","content":"pub fn new_1(x: List(a), y: fn() -&gt; List(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.new_1\ngleam_zlists/interop new_1","url":"gleam_zlists/interop.html#new_1"},{"doc":"gleam_zlists/interop","title":"new_2","content":"pub fn new_2(x: ZList(a), y: fn() -&gt; ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.new_2\ngleam_zlists/interop new_2","url":"gleam_zlists/interop.html#new_2"},{"doc":"gleam_zlists/interop","title":"print","content":"pub fn print(x: ZList(a)) -&gt; Nil\n\nSynonyms:\ngleam_zlists/interop.print\ngleam_zlists/interop print","url":"gleam_zlists/interop.html#print"},{"doc":"gleam_zlists/interop","title":"recurrent_2","content":"pub fn recurrent_2(x: a, y: fn(a) -&gt; a) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.recurrent_2\ngleam_zlists/interop recurrent_2","url":"gleam_zlists/interop.html#recurrent_2"},{"doc":"gleam_zlists/interop","title":"recurrent_3","content":"pub fn recurrent_3(\n  x: a,\n  y: b,\n  z: fn(a, b) -&gt; #(a, b),\n) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.recurrent_3\ngleam_zlists/interop recurrent_3","url":"gleam_zlists/interop.html#recurrent_3"},{"doc":"gleam_zlists/interop","title":"scroll","content":"pub fn scroll(x: Int, y: ZList(a)) -&gt; #(List(a), ZList(a))\n\nSynonyms:\ngleam_zlists/interop.scroll\ngleam_zlists/interop scroll","url":"gleam_zlists/interop.html#scroll"},{"doc":"gleam_zlists/interop","title":"seq","content":"pub fn seq(x: Int, y: Int, z: Int) -&gt; ZList(Int)\n\nSynonyms:\ngleam_zlists/interop.seq\ngleam_zlists/interop seq","url":"gleam_zlists/interop.html#seq"},{"doc":"gleam_zlists/interop","title":"splitwith","content":"pub fn splitwith(\n  x: fn(a) -&gt; Bool,\n  y: ZList(a),\n) -&gt; #(List(a), ZList(a))\n\nSynonyms:\ngleam_zlists/interop.splitwith\ngleam_zlists/interop splitwith","url":"gleam_zlists/interop.html#splitwith"},{"doc":"gleam_zlists/interop","title":"take","content":"pub fn take(x: Int, y: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.take\ngleam_zlists/interop take","url":"gleam_zlists/interop.html#take"},{"doc":"gleam_zlists/interop","title":"takewhile","content":"pub fn takewhile(x: fn(a) -&gt; Bool, y: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.takewhile\ngleam_zlists/interop takewhile","url":"gleam_zlists/interop.html#takewhile"},{"doc":"gleam_zlists/interop","title":"unique_1","content":"pub fn unique_1(x: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.unique_1\ngleam_zlists/interop unique_1","url":"gleam_zlists/interop.html#unique_1"},{"doc":"gleam_zlists/interop","title":"unique_2","content":"pub fn unique_2(x: fn(a, a) -&gt; Bool, y: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interop.unique_2\ngleam_zlists/interop unique_2","url":"gleam_zlists/interop.html#unique_2"},{"doc":"gleam_zlists/interop","title":"zip","content":"pub fn zip(x: ZList(a), y: ZList(b)) -&gt; ZList(#(a, b))\n\nSynonyms:\ngleam_zlists/interop.zip\ngleam_zlists/interop zip","url":"gleam_zlists/interop.html#zip"},{"doc":"gleam_zlists/interop","title":"ziph","content":"pub fn ziph(x: ZList(a), y: ZList(b)) -&gt; ZList(#(a, b))\n\nSynonyms:\ngleam_zlists/interop.ziph\ngleam_zlists/interop ziph","url":"gleam_zlists/interop.html#ziph"},{"doc":"gleam_zlists/interop","title":"gleam_zlists/interop","content":"","url":"gleam_zlists/interop.html"},{"doc":"gleam_zlists/interface","title":"ZList","content":"pub type ZList(t) =\n  interop.ZList(t)\n\n\nSynonyms:\ngleam_zlists/interface.ZList\ngleam_zlists/interface ZList","url":"gleam_zlists/interface.html#ZList"},{"doc":"gleam_zlists/interface","title":"append","content":"pub fn append(zlsts: ZList(ZList(a))) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.append\ngleam_zlists/interface append","url":"gleam_zlists/interface.html#append"},{"doc":"gleam_zlists/interface","title":"cartesian","content":"pub fn cartesian(zl_1: ZList(a), zl_2: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.cartesian\ngleam_zlists/interface cartesian","url":"gleam_zlists/interface.html#cartesian"},{"doc":"gleam_zlists/interface","title":"count","content":"pub fn count(zl: ZList(a)) -&gt; Int\n\nSynonyms:\ngleam_zlists/interface.count\ngleam_zlists/interface count","url":"gleam_zlists/interface.html#count"},{"doc":"gleam_zlists/interface","title":"drop","content":"pub fn drop(n: Int, zl: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.drop\ngleam_zlists/interface drop","url":"gleam_zlists/interface.html#drop"},{"doc":"gleam_zlists/interface","title":"dropwhile","content":"pub fn dropwhile(pred: fn(a) -&gt; Bool, zl: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.dropwhile\ngleam_zlists/interface dropwhile","url":"gleam_zlists/interface.html#dropwhile"},{"doc":"gleam_zlists/interface","title":"expand","content":"pub fn expand(zl: ZList(a)) -&gt; List(a)\n\nSynonyms:\ngleam_zlists/interface.expand\ngleam_zlists/interface expand","url":"gleam_zlists/interface.html#expand"},{"doc":"gleam_zlists/interface","title":"filter","content":"pub fn filter(pred: fn(a) -&gt; Bool, zl: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.filter\ngleam_zlists/interface filter","url":"gleam_zlists/interface.html#filter"},{"doc":"gleam_zlists/interface","title":"foldl","content":"pub fn foldl(f: fn(a, b) -&gt; b, accum: b, zl: ZList(a)) -&gt; b\n\nSynonyms:\ngleam_zlists/interface.foldl\ngleam_zlists/interface foldl","url":"gleam_zlists/interface.html#foldl"},{"doc":"gleam_zlists/interface","title":"foreach","content":"pub fn foreach(f: fn(a) -&gt; b, zl: ZList(a)) -&gt; Nil\n\nSynonyms:\ngleam_zlists/interface.foreach\ngleam_zlists/interface foreach","url":"gleam_zlists/interface.html#foreach"},{"doc":"gleam_zlists/interface","title":"generate","content":"pub fn generate(zl: ZList(a), f: fn(a) -&gt; ZList(b)) -&gt; ZList(b)\n\nSynonyms:\ngleam_zlists/interface.generate\ngleam_zlists/interface generate","url":"gleam_zlists/interface.html#generate"},{"doc":"gleam_zlists/interface","title":"map","content":"pub fn map(f: fn(a) -&gt; b, zl: ZList(a)) -&gt; ZList(b)\n\nSynonyms:\ngleam_zlists/interface.map\ngleam_zlists/interface map","url":"gleam_zlists/interface.html#map"},{"doc":"gleam_zlists/interface","title":"merge","content":"pub fn merge(zl_1: ZList(a), zl_2: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.merge\ngleam_zlists/interface merge","url":"gleam_zlists/interface.html#merge"},{"doc":"gleam_zlists/interface","title":"new_1","content":"pub fn new_1(ls: List(a), f: fn() -&gt; List(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.new_1\ngleam_zlists/interface new_1","url":"gleam_zlists/interface.html#new_1"},{"doc":"gleam_zlists/interface","title":"new_2","content":"pub fn new_2(ls: ZList(a), f: fn() -&gt; ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.new_2\ngleam_zlists/interface new_2","url":"gleam_zlists/interface.html#new_2"},{"doc":"gleam_zlists/interface","title":"print","content":"pub fn print(zl: ZList(a)) -&gt; Nil\n\nSynonyms:\ngleam_zlists/interface.print\ngleam_zlists/interface print","url":"gleam_zlists/interface.html#print"},{"doc":"gleam_zlists/interface","title":"recurrent_2","content":"pub fn recurrent_2(elem: a, f: fn(a) -&gt; a) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.recurrent_2\ngleam_zlists/interface recurrent_2","url":"gleam_zlists/interface.html#recurrent_2"},{"doc":"gleam_zlists/interface","title":"recurrent_3","content":"pub fn recurrent_3(\n  elem: a,\n  elem_1: b,\n  f: fn(a, b) -&gt; #(a, b),\n) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.recurrent_3\ngleam_zlists/interface recurrent_3","url":"gleam_zlists/interface.html#recurrent_3"},{"doc":"gleam_zlists/interface","title":"scroll","content":"pub fn scroll(n: Int, zl: ZList(a)) -&gt; #(List(a), ZList(a))\n\nSynonyms:\ngleam_zlists/interface.scroll\ngleam_zlists/interface scroll","url":"gleam_zlists/interface.html#scroll"},{"doc":"gleam_zlists/interface","title":"seq","content":"pub fn seq(from: Int, to: Int, incr: Int) -&gt; ZList(Int)\n\nSynonyms:\ngleam_zlists/interface.seq\ngleam_zlists/interface seq","url":"gleam_zlists/interface.html#seq"},{"doc":"gleam_zlists/interface","title":"splitwith","content":"pub fn splitwith(\n  pred: fn(a) -&gt; Bool,\n  zl: ZList(a),\n) -&gt; #(List(a), ZList(a))\n\nSynonyms:\ngleam_zlists/interface.splitwith\ngleam_zlists/interface splitwith","url":"gleam_zlists/interface.html#splitwith"},{"doc":"gleam_zlists/interface","title":"take","content":"pub fn take(n: Int, zl: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.take\ngleam_zlists/interface take","url":"gleam_zlists/interface.html#take"},{"doc":"gleam_zlists/interface","title":"takewhile","content":"pub fn takewhile(pred: fn(a) -&gt; Bool, zl: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.takewhile\ngleam_zlists/interface takewhile","url":"gleam_zlists/interface.html#takewhile"},{"doc":"gleam_zlists/interface","title":"unique_1","content":"pub fn unique_1(zl: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.unique_1\ngleam_zlists/interface unique_1","url":"gleam_zlists/interface.html#unique_1"},{"doc":"gleam_zlists/interface","title":"unique_2","content":"pub fn unique_2(pred: fn(a, a) -&gt; Bool, zl: ZList(a)) -&gt; ZList(a)\n\nSynonyms:\ngleam_zlists/interface.unique_2\ngleam_zlists/interface unique_2","url":"gleam_zlists/interface.html#unique_2"},{"doc":"gleam_zlists/interface","title":"zip","content":"pub fn zip(zl_1: ZList(a), zl_2: ZList(b)) -&gt; ZList(#(a, b))\n\nSynonyms:\ngleam_zlists/interface.zip\ngleam_zlists/interface zip","url":"gleam_zlists/interface.html#zip"},{"doc":"gleam_zlists/interface","title":"ziph","content":"pub fn ziph(zl_1: ZList(a), zl_2: ZList(b)) -&gt; ZList(#(a, b))\n\nSynonyms:\ngleam_zlists/interface.ziph\ngleam_zlists/interface ziph","url":"gleam_zlists/interface.html#ziph"},{"doc":"gleam_zlists/interface","title":"gleam_zlists/interface","content":"","url":"gleam_zlists/interface.html"},{"doc":"gleam_zlists","title":"ZList","content":"pub type ZList(t) =\n  api.ZList(t)\n A type for representing lazy lists.\n\nSynonyms:\ngleam_zlists.ZList\ngleam_zlists ZList","url":"gleam_zlists.html#ZList"},{"doc":"gleam_zlists","title":"all","content":"pub fn all(zlist: ZList(a), fun: fn(a) -&gt; Bool) -&gt; Bool\n Iterates over the `zlist` and invokes `fun` on each element.\n When an invocation of `fun` returns `False`, iteration stops immediately and `False` is returned.\n In all other cases `True` is returned.\n\n  ## Examples\n\n \n [2, 4, 6]\n |&gt; of_list\n |&gt; all(int.is_even)\n True\n \n\n \n [2, 3, 4]\n |&gt; of_list\n |&gt; all(int.is_even)\n False\n \n\n \n []\n |&gt; of_list\n |&gt; all(fn(x) { x &gt; 0 })\n True\n \n\nSynonyms:\ngleam_zlists.all\ngleam_zlists all","url":"gleam_zlists.html#all"},{"doc":"gleam_zlists","title":"any","content":"pub fn any(zlist: ZList(a), fun: fn(a) -&gt; Bool) -&gt; Bool\n Iterates over the `zlist` and invokes `fun` on each element.\n When an invocation of `fun` returns `True`, iteration stops immediately and `True` is returned.\n In all other cases `False` is returned.\n\n  ## Examples\n\n \n [2, 4, 6]\n |&gt; of_list\n |&gt; any(int.is_odd)\n False\n \n\n \n [2, 3, 4]\n |&gt; of_list\n |&gt; any(int.is_odd)\n True\n \n\n \n []\n |&gt; of_list\n |&gt; any(fn(x) { x &gt; 0 })\n False\n \n\nSynonyms:\ngleam_zlists.any\ngleam_zlists any","url":"gleam_zlists.html#any"},{"doc":"gleam_zlists","title":"append","content":"pub fn append(left: ZList(a), right: ZList(a)) -&gt; ZList(a)\n Creates a ZList that contains the first argument, followed by the second.\n\n  ## Examples\n\n \n append(range(1, 3, 1), range(4, 6, 1))\n |&gt; to_list\n [1, 2, 3, 4, 5, 6]\n \n\nSynonyms:\ngleam_zlists.append\ngleam_zlists append","url":"gleam_zlists.html#append"},{"doc":"gleam_zlists","title":"concat","content":"pub fn concat(zlists: ZList(ZList(a))) -&gt; ZList(a)\n Given an `ZList` of `ZList`, concatenates them into a single `ZList`.\n\n  ## Examples\n\n \n [range(1, 3, 1), range(4, 6, 1), range(7, 9, 1)]\n |&gt; of_list\n |&gt; concat\n |&gt; to_list\n [1, 2, 3, 4, 5, 6, 7, 8, 9]\n \n\nSynonyms:\ngleam_zlists.concat\ngleam_zlists concat","url":"gleam_zlists.html#concat"},{"doc":"gleam_zlists","title":"cons","content":"pub fn cons(zlist: ZList(a), first_value: a) -&gt; ZList(a)\n Return a new `ZList` which contains the `first_value` followed by the `zlist`.\n\n  ## Examples\n\n \n range(1, 3, 1)\n |&gt; cons(0)\n |&gt; to_list\n [0, 1, 2, 3]\n \n\nSynonyms:\ngleam_zlists.cons\ngleam_zlists cons","url":"gleam_zlists.html#cons"},{"doc":"gleam_zlists","title":"count","content":"pub fn count(zlist: ZList(a)) -&gt; Int\n Returns the size of the `zlist`.\n\n  ## Examples\n\n \n [1, 2, 3]\n |&gt; of_list\n |&gt; count\n 3\n \n\nSynonyms:\ngleam_zlists.count\ngleam_zlists count","url":"gleam_zlists.html#count"},{"doc":"gleam_zlists","title":"dedup","content":"pub fn dedup(zlist: ZList(a)) -&gt; ZList(a)\n Creates a `ZList` that only emits elements if they are different from the last emitted element.\n This function only ever needs to store the last emitted element.\n\n  ## Examples\n\n \n  [1, 2, 3, 3, 2, 1]\n  |&gt; of_list\n  |&gt; dedup\n  |&gt; to_list\n  [1, 2, 3, 2, 1]\n \n\nSynonyms:\ngleam_zlists.dedup\ngleam_zlists dedup","url":"gleam_zlists.html#dedup"},{"doc":"gleam_zlists","title":"drop","content":"pub fn drop(zlist: ZList(a), n: Int) -&gt; ZList(a)\n Lazily drops the next `n` elements from the `zlist`.\n `n` should **not** be **negative**.\n\n  ## Examples\n\n \n [1, 2, 3]\n |&gt; of_list\n |&gt; drop(2)\n |&gt; to_list\n [3]\n \n\nSynonyms:\ngleam_zlists.drop\ngleam_zlists drop","url":"gleam_zlists.html#drop"},{"doc":"gleam_zlists","title":"drop_while","content":"pub fn drop_while(\n  zlist: ZList(a),\n  fun: fn(a) -&gt; Bool,\n) -&gt; ZList(a)\n Drops elements at the beginning of the `zlist` while `fun` returns a `True`.\n\n  ## Examples\n\n \n [1, 2, 3, 2, 1]\n |&gt; of_list\n |&gt; drop_while(fn(x) { x &lt; 3 })\n |&gt; to_list\n [3, 2, 1]\n \n\nSynonyms:\ngleam_zlists.drop_while\ngleam_zlists drop_while","url":"gleam_zlists.html#drop_while"},{"doc":"gleam_zlists","title":"each","content":"pub fn each(zlist: ZList(a), fun: fn(a) -&gt; b) -&gt; Nil\n Executes the given function for each element.\n Useful for adding side effects (like printing) to a `ZList`.\n\nSynonyms:\ngleam_zlists.each\ngleam_zlists each","url":"gleam_zlists.html#each"},{"doc":"gleam_zlists","title":"fetch","content":"pub fn fetch(zlist: ZList(a), index: Int) -&gt; Result(a, Nil)\n Finds the element at the given `index` (zero-based).\n Returns `Ok(element)` if found, otherwise `Error(Nil)`.\n\n  ## Examples\n\n \n [2, 4, 6]\n |&gt; of_list\n |&gt; fetch(1)\n Ok(4)\n \n\n \n [2, 4, 6]\n |&gt; of_list\n |&gt; fetch(4)\n Error(Nil)\n \n\nSynonyms:\ngleam_zlists.fetch\ngleam_zlists fetch","url":"gleam_zlists.html#fetch"},{"doc":"gleam_zlists","title":"filter","content":"pub fn filter(zlist: ZList(a), fun: fn(a) -&gt; Bool) -&gt; ZList(a)\n Filters the `zlist`, i.e. returns only those elements for which fun returns `True`.\n\n  ## Examples\n\n \n [1, 2, 3]\n |&gt; of_list\n |&gt; filter(fn(x) { int.is_even(x) })\n |&gt; to_list\n [2]\n \n\nSynonyms:\ngleam_zlists.filter\ngleam_zlists filter","url":"gleam_zlists.html#filter"},{"doc":"gleam_zlists","title":"find","content":"pub fn find(\n  zlist: ZList(a),\n  fun: fn(a) -&gt; Bool,\n) -&gt; Result(a, Nil)\n Returns `Ok(element)` for the first element that `fun` returns `True`.\n If no such element is found, returns `Error(Nil)`.\n\n  ## Examples\n\n \n [2, 3, 4]\n |&gt; of_list\n |&gt; find(int.is_odd)\n Ok(3)\n \n\n \n [2, 4, 6]\n |&gt; of_list\n |&gt; find(int.is_odd)\n Error(Nil)\n \n\nSynonyms:\ngleam_zlists.find\ngleam_zlists find","url":"gleam_zlists.html#find"},{"doc":"gleam_zlists","title":"flat_map","content":"pub fn flat_map(\n  zlist: ZList(a),\n  fun: fn(a) -&gt; ZList(b),\n) -&gt; ZList(b)\n Maps the given `fun` over `zlist` and flattens the result.\n This function returns a new `ZList` built by appending the result of invoking `fun` on each element of `zlist` together.\n\n  ## Examples\n\n \n [1, 2, 3]\n |&gt; of_list\n |&gt; flat_map(fn(x) { of_list([x, 2 * x]) })\n |&gt; to_list\n [1, 2, 2, 4, 3, 6]\n \n\nSynonyms:\ngleam_zlists.flat_map\ngleam_zlists flat_map","url":"gleam_zlists.html#flat_map"},{"doc":"gleam_zlists","title":"has_member","content":"pub fn has_member(zlist: ZList(a), element: a) -&gt; Bool\n Checks if `element` exists within the `zlist`.\n\n  ## Examples\n\n \n [2, 3, 4]\n |&gt; of_list\n |&gt; has_member(3)\n True\n \n\n \n [2, 4, 6]\n |&gt; of_list\n |&gt; has_member(8)\n False\n \n\nSynonyms:\ngleam_zlists.has_member\ngleam_zlists has_member","url":"gleam_zlists.html#has_member"},{"doc":"gleam_zlists","title":"head","content":"pub fn head(zlist: ZList(a)) -&gt; Result(a, Nil)\n Gets the first element of the `zlist`, if there is one.\n\n  ## Examples\n\n \n range(1, 3, 1)\n |&gt; head\n Ok(1)\n \n\n \n new()\n |&gt; head\n Error(Nil)\n \n\nSynonyms:\ngleam_zlists.head\ngleam_zlists head","url":"gleam_zlists.html#head"},{"doc":"gleam_zlists","title":"indices","content":"pub fn indices() -&gt; ZList(Int)\n Returns an infinite `ZList` that contains the non-negative integers (sorted).\n\n  ## Examples\n\n \n indices()\n |&gt; take(5)\n |&gt; to_list\n [0, 1, 2, 3, 4]\n \n\nSynonyms:\ngleam_zlists.indices\ngleam_zlists indices","url":"gleam_zlists.html#indices"},{"doc":"gleam_zlists","title":"is_empty","content":"pub fn is_empty(zlist: ZList(a)) -&gt; Bool\n Determines if the `ZList` is empty.\n\n  ## Examples\n\n \n []\n |&gt; of_list\n |&gt; is_empty\n True\n \n\n \n [1, 2, 3]\n |&gt; of_list\n |&gt; is_empty\n False\n \n\nSynonyms:\ngleam_zlists.is_empty\ngleam_zlists is_empty","url":"gleam_zlists.html#is_empty"},{"doc":"gleam_zlists","title":"iterate","content":"pub fn iterate(start_value: a, next_fun: fn(a) -&gt; a) -&gt; ZList(a)\n Emits a `ZList` of values, starting with `start_value`.\n Successive values are generated by calling `next_fun` on the previous value.\n\n  ## Examples\n\n \n iterate(0, fn(x) { x + 1 })\n |&gt; take(5)\n |&gt; to_list\n [0, 1, 2, 3, 4]\n \n\nSynonyms:\ngleam_zlists.iterate\ngleam_zlists iterate","url":"gleam_zlists.html#iterate"},{"doc":"gleam_zlists","title":"map","content":"pub fn map(zlist: ZList(a), fun: fn(a) -&gt; b) -&gt; ZList(b)\n Returns a `ZList` where each element is the result of invoking `fun` on each corresponding element of `zlist`.\n\n  ## Examples\n\n \n [1, 2, 3]\n |&gt; of_list\n |&gt; map(fn(x) { 2 * x })\n |&gt; to_list\n [2, 4, 6]\n \n\nSynonyms:\ngleam_zlists.map\ngleam_zlists map","url":"gleam_zlists.html#map"},{"doc":"gleam_zlists","title":"max","content":"pub fn max(zlist: ZList(Float)) -&gt; Result(Float, Nil)\n Returns the maximum element in the `zlist`.\n If the `zlist` is empty, `Error(Nil)` is returned.\n The elements should be `Float` numbers.\n\n  ## Examples\n\n \n [1.0, 3.0, 0.0, 2.0]\n |&gt; of_list\n |&gt; max\n Ok(3.0)\n \n\nSynonyms:\ngleam_zlists.max\ngleam_zlists max","url":"gleam_zlists.html#max"},{"doc":"gleam_zlists","title":"min","content":"pub fn min(zlist: ZList(Float)) -&gt; Result(Float, Nil)\n Returns the minimum element in the `zlist`.\n If the `zlist` is empty, `Error(Nil)` is returned.\n The elements should be `Float` numbers.\n\n  ## Examples\n\n \n [1.0, 3.0, 0.0, 2.0]\n |&gt; of_list\n |&gt; min\n Ok(0.0)\n \n\nSynonyms:\ngleam_zlists.min\ngleam_zlists min","url":"gleam_zlists.html#min"},{"doc":"gleam_zlists","title":"new","content":"pub fn new() -&gt; ZList(a)\n Creates an empty `ZList`.\n\n  ## Examples\n\n \n new()\n |&gt; to_list\n []\n \n\nSynonyms:\ngleam_zlists.new\ngleam_zlists new","url":"gleam_zlists.html#new"},{"doc":"gleam_zlists","title":"of_iterator","content":"pub fn of_iterator(iter: Iterator(a)) -&gt; ZList(a)\n Converts the `iter` into a `ZList`.\n\n  ## Examples\n\n \n [1, 2]\n |&gt; iterator.from_list\n |&gt; iterator.cycle\n |&gt; of_iterator\n |&gt; take(5)\n |&gt; to_list\n [1, 2, 1, 2, 1]\n \n\n \n iterator.unfold(0, fn(n) { Next(n, n + 1) })\n |&gt; of_iterator\n |&gt; take(3)\n |&gt; to_list\n [0, 1, 2]\n \n\nSynonyms:\ngleam_zlists.of_iterator\ngleam_zlists of_iterator","url":"gleam_zlists.html#of_iterator"},{"doc":"gleam_zlists","title":"of_list","content":"pub fn of_list(list: List(a)) -&gt; ZList(a)\n Converts a `list` to `ZList`.\n\nSynonyms:\ngleam_zlists.of_list\ngleam_zlists of_list","url":"gleam_zlists.html#of_list"},{"doc":"gleam_zlists","title":"range","content":"pub fn range(first: Int, last: Int, step: Int) -&gt; ZList(Int)\n Returns a lazy range from `first` to `last` (included).\n The difference between one term and the next equals to `step`.\n The `step` should be **positive**.\n\n  ## Examples\n\n \n range(0, 3, 1)\n |&gt; to_list\n [0, 1, 2, 3]\n \n\n \n range(-3, 5, 2)\n |&gt; to_list\n [-3, -1, 1, 3, 5]\n \n\nSynonyms:\ngleam_zlists.range\ngleam_zlists range","url":"gleam_zlists.html#range"},{"doc":"gleam_zlists","title":"reduce","content":"pub fn reduce(zlist: ZList(a), acc: b, fun: fn(a, b) -&gt; b) -&gt; b\n Invokes `fun` for each element in the `zlist` with the accumulator.\n The initial value of the accumulator is `acc`.\n The function is invoked for each element in the `zlist` with the accumulator.\n The result returned by the function is used as the accumulator for the next iteration.\n The function returns the last accumulator.\n\n  ## Examples\n\n \n [1, 2, 3]\n |&gt; of_list\n |&gt; reduce(0, fn(x, acc) { x + acc })\n 6\n \n\nSynonyms:\ngleam_zlists.reduce\ngleam_zlists reduce","url":"gleam_zlists.html#reduce"},{"doc":"gleam_zlists","title":"reverse","content":"pub fn reverse(zlist: ZList(a)) -&gt; ZList(a)\n Returns a `ZList` of the elements in `zlist` in reverse order.\n\n  ## Examples\n\n \n [1, 2, 3]\n |&gt; of_list\n |&gt; reverse\n |&gt; to_list\n [3, 2, 1]\n \n\nSynonyms:\ngleam_zlists.reverse\ngleam_zlists reverse","url":"gleam_zlists.html#reverse"},{"doc":"gleam_zlists","title":"singleton","content":"pub fn singleton(value: a) -&gt; ZList(a)\n Creates a `ZList` of just one specified `value`.\n\n  ## Examples\n\n \n 10\n |&gt; singleton\n |&gt; to_list\n [10]\n \n\nSynonyms:\ngleam_zlists.singleton\ngleam_zlists singleton","url":"gleam_zlists.html#singleton"},{"doc":"gleam_zlists","title":"slice","content":"pub fn slice(\n  zlist: ZList(a),\n  start_index: Int,\n  amount: Int,\n) -&gt; ZList(a)\n Returns a subset `ZList` of the given `zlist`, from `start_index` (zero-based) with `amount` number of elements if available.\n Given an `zlist`, it drops elements right before element `start_index`, then takes `amount` of elements, returning as many elements as possible if there are not enough elements.\n\n  ## Examples\n\n \n range(1, 100, 1)\n |&gt; slice(5, 10)\n |&gt; to_list\n [6, 7, 8, 9, 10, 11, 12, 13, 14, 15]\n \n\n \n range(1, 10, 1)\n |&gt; slice(5, 100)\n |&gt; to_list\n [6, 7, 8, 9, 10]\n \n\nSynonyms:\ngleam_zlists.slice\ngleam_zlists slice","url":"gleam_zlists.html#slice"},{"doc":"gleam_zlists","title":"split","content":"pub fn split(zlist: ZList(a), n: Int) -&gt; #(List(a), ZList(a))\n Splits the `zlist` into a `List` and a `ZList`, leaving `n` elements in the first one.\n\n  ## Examples\n\n \n let #(ls_a, zls_b) =\n   [1, 2, 3]\n   |&gt; of_list\n   |&gt; split(2)\n let ls_b = to_list(zls_b)\n #(ls_a, ls_b)\n #([1, 2], [3])\n \n\nSynonyms:\ngleam_zlists.split\ngleam_zlists split","url":"gleam_zlists.html#split"},{"doc":"gleam_zlists","title":"split_while","content":"pub fn split_while(\n  zlist: ZList(a),\n  fun: fn(a) -&gt; Bool,\n) -&gt; #(List(a), ZList(a))\n Splits `zlist` into a `List` and a `ZList` at the position of the element for which `fun` returns `False` for the first time.\n\n  ## Examples\n\n \n let #(ls_a, zls_b) =\n   [1, 2, 3, 4]\n   |&gt; of_list\n   |&gt; split_while(fn(x) { x &lt; 3 })\n let ls_b = to_list(zls_b)\n #(ls_a, ls_b)\n #([1, 2], [3, 4])\n \n\nSynonyms:\ngleam_zlists.split_while\ngleam_zlists split_while","url":"gleam_zlists.html#split_while"},{"doc":"gleam_zlists","title":"sum","content":"pub fn sum(zlist: ZList(Float)) -&gt; Float\n Returns the sum of all elements. The elements should be `Float` numbers.\n\n  ## Examples\n\n \n [0.0, 1.0, 2.0, 3.0, 4.0]\n |&gt; of_list\n |&gt; sum\n 10.0\n \n\nSynonyms:\ngleam_zlists.sum\ngleam_zlists sum","url":"gleam_zlists.html#sum"},{"doc":"gleam_zlists","title":"tail","content":"pub fn tail(zlist: ZList(a)) -&gt; Result(ZList(a), Nil)\n Gets the `zlist` minus the first element. If the `zlist` is empty, `Error(Nil)` is returned.\n\n  ## Examples\n\n \n range(1, 3, 1)\n |&gt; tail\n |&gt; result.map(to_list)\n Ok([2, 3])\n \n\n \n new()\n |&gt; tail\n Error(Nil)\n \n\nSynonyms:\ngleam_zlists.tail\ngleam_zlists tail","url":"gleam_zlists.html#tail"},{"doc":"gleam_zlists","title":"take","content":"pub fn take(zlist: ZList(a), n: Int) -&gt; ZList(a)\n Lazily takes the first `n` elements from the `zlist`.\n The `n` should **not** be **negative**.\n\n  ## Examples\n\n \n range(1, 100, 1)\n |&gt; take(5)\n |&gt; to_list\n [1, 2, 3, 4, 5]\n \n\nSynonyms:\ngleam_zlists.take\ngleam_zlists take","url":"gleam_zlists.html#take"},{"doc":"gleam_zlists","title":"take_while","content":"pub fn take_while(\n  zlist: ZList(a),\n  fun: fn(a) -&gt; Bool,\n) -&gt; ZList(a)\n Lazily takes elements of the `zlist` while the given function returns `True`.\n\n  ## Examples\n\n \n range(1, 100, 1)\n |&gt; take_while(fn(x) { x &lt;= 5 })\n |&gt; to_list\n [1, 2, 3, 4, 5]\n \n\nSynonyms:\ngleam_zlists.take_while\ngleam_zlists take_while","url":"gleam_zlists.html#take_while"},{"doc":"gleam_zlists","title":"to_iterator","content":"pub fn to_iterator(zlist: ZList(a)) -&gt; Iterator(a)\n Converts the `zlist` into an `Iterator`.\n\n  ## Examples\n\n \n indices()\n |&gt; to_iterator\n |&gt; iterator.take(5)\n [0, 1, 2, 3, 4]\n \n\nSynonyms:\ngleam_zlists.to_iterator\ngleam_zlists to_iterator","url":"gleam_zlists.html#to_iterator"},{"doc":"gleam_zlists","title":"to_list","content":"pub fn to_list(zlist: ZList(a)) -&gt; List(a)\n Converts a `zlist` to `List`.\n\n  ## Examples\n\n \n range(0, 3, 1)\n |&gt; to_list\n [0, 1, 2, 3]\n \n\nSynonyms:\ngleam_zlists.to_list\ngleam_zlists to_list","url":"gleam_zlists.html#to_list"},{"doc":"gleam_zlists","title":"uncons","content":"pub fn uncons(zlist: ZList(a)) -&gt; Result(#(a, ZList(a)), Nil)\n Returns the # of the first element and the tail of the `zlist`. If the `zlist` is empty, `Error(Nil)` is returned.\n\n  ## Examples\n\n \n range(1, 3, 1)\n |&gt; uncons\n |&gt; result.map(fn(res) {\n   let #(hd, tl) = res\n   #(hd, to_list(tl))\n })\n Ok(#(1, [2, 3]))\n \n\nSynonyms:\ngleam_zlists.uncons\ngleam_zlists uncons","url":"gleam_zlists.html#uncons"},{"doc":"gleam_zlists","title":"unzip","content":"pub fn unzip(zlist: ZList(#(a, b))) -&gt; #(ZList(a), ZList(b))\n It takes a `ZList` with elements being two-element `#`s and returns a `#` with two `ZList`s.\n Each `ZList` is formed by the first and second element of each #, respectively.\n\n  ## Examples\n\n \n let #(xs, ys) =\n   [#(&quot;a&quot;, 1), #(&quot;b&quot;, 2), #(&quot;c&quot;, 3)]\n   |&gt; of_list\n   |&gt; unzip\n #(to_list(xs), to_list(ys))\n #([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;], [1, 2, 3])\n \n\nSynonyms:\ngleam_zlists.unzip\ngleam_zlists unzip","url":"gleam_zlists.html#unzip"},{"doc":"gleam_zlists","title":"with_index","content":"pub fn with_index(zlist: ZList(a)) -&gt; ZList(#(a, Int))\n Returns the `zlist` with each element wrapped in a # alongside its index.\n\n  ## Examples\n\n \n [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]\n |&gt; of_list\n |&gt; with_index\n |&gt; to_list\n [#(&quot;a&quot;, 0), #(&quot;b&quot;, 1), #(&quot;c&quot;, 2)]\n \n\nSynonyms:\ngleam_zlists.with_index\ngleam_zlists with_index","url":"gleam_zlists.html#with_index"},{"doc":"gleam_zlists","title":"zip","content":"pub fn zip(left: ZList(a), right: ZList(b)) -&gt; ZList(#(a, b))\n Zips `left` and `right` together, lazily.\n The zipping finishes as soon as any `ZList` completes.\n\n  ## Examples\n\n \n let left = of_list([1, 2, 3])\n let right = of_list([&quot;foo&quot;, &quot;bar&quot;, &quot;baz&quot;])\n zip(left, right)\n |&gt; to_list\n [#(1, &quot;foo&quot;), #(2, &quot;bar&quot;), #(3, &quot;baz&quot;)]\n \n\nSynonyms:\ngleam_zlists.zip\ngleam_zlists zip","url":"gleam_zlists.html#zip"},{"doc":"gleam_zlists","title":"gleam_zlists","content":" This module contains some useful functions for working with **lazy lists**.\n\n For more information see [this website](https://github.com/mrdimosthenis/gleam_zlists).","url":"gleam_zlists.html"}]);